/*
jQuery simpleSlider
version 1.0
par Gildas P.
https://www.playingwithpixels.gildasp.fr
*/

$.fn.simpleSlider = function(params){	

	params = $.extend({
		duration: 600,
		easing: 'ease',
		next: null,
		prev: null,
		stretch: null,
		speed: 0,
		viewport: null
	}, params);

	$(this).each(function(){
		new SimpleSlider($(this), params);
	});

	return this;
};

class SimpleSlider {
	constructor(cible, params) {
		this.$dom = cible; // sert peu
		this.$viewport = cible;
		if(params.viewport!=null){
			// si on veut complexifier le slider...
			this.$viewport = cible.find(params.viewport);
			// ça permet de séparer les UI du viewport...
		}
		this.$ul = this.$viewport.find('ul');
		this.$lis = this.$viewport.find('li');

		this.params = params;
		this.index = 0;
		this.initCSS();


		if(params.speed>0){
			this.autoPlay();
			this.notClickable();
		} else {
			if(params.next==null){
				this.initUI();
			} else {
				this.initBtns();
			}
		}
			
	}
	initCSS(){
		// étirer/placer horizontalement les slides
		// c'est du css
		this.$viewport.css({
			overflow: 'hidden',
			cursor: 'pointer'
		});
		this.$ul.css({
			width: (this.$lis.length*100)+'%',
			display: 'flex',
			margin: 0, padding: 0,
			x: 0
		});
		this.$lis.css({
			width: (100/this.$lis.length)+'%',
			margin: 0, padding: 0,
			overflow: 'hidden'
		});

		// ajustement des images
		if(this.params.stretch!=null){
			switch(this.params.stretch){
				case "width":
					this.$lis.find('img').css({
						width: '100%'
					});
					break;
				case "height": // non-documenté sur le site...
					this.$lis.find('img').css({
						height: '100%'
					});
					break;
				case "cover":
					this.$viewport.find('ul, li').css({
						height: '100%'
					});
					this.$viewport.find('img').css({
						width: '100%',
						height: '100%',
						'object-fit': 'cover'
					});
					break;
				case "contain":
					this.$viewport.find('ul, li').css({
						height: '100%'
					});
					this.$viewport.find('img').css({
						width: '100%',
						height: '100%',
						'object-fit': 'contain'
					});
					break;
			}
		}
	}
	
	goto(num){
		if(num<0){
			num = this.$lis.length-1;
		} else if(num>=this.$lis.length){
			num = 0;
		}
		var unit = 100/this.$lis.length;
		this.$ul.transition({ // $().transition() c'est la lib jquery transitCSS3...
			x: (-num*unit)+'%'
		}, this.params.duration, this.params.easing);
		this.index = num;
	}
	next(){ this.goto(this.index+1); };
	prev(){ this.goto(this.index-1); };

	autoPlay(){
		var self = this;
		if(this._loop) clearTimeout(this._loop);
		this._loop = setTimeout(function(){
			self.next();
			self.autoPlay();
		}, this.params.speed);
	}

	// avancer au click
	initUI(){
		var self = this;
		this.$viewport.on('click', function(){
			self.next();
		});
	}
	initBtns(){
		var $next = this.$dom.find(this.params.next);
		var $prev = this.$dom.find(this.params.prev);
		var self = this;
		if($next.length>0){
			$next.on('click', function(){
				self.next();
			});
		}
		if($prev.length>0){
			$prev.on('click', function(){
				self.prev();
			});

			// pas de curseur sur le viewport
			this.notClickable();
		}
	}
	notClickable(){ // pas de curseur "main cliquable"
		this.$viewport.css({
			cursor: 'auto'
		});
	}
};